==> primefaces-14.0.0-sources.jar: org/primefaces/model/TreeNode.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2009-2024 PrimeTek Informatics
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.primefaces.model;

import java.util.List;

public interface TreeNode<T> {

    String getType();

    void setType(String type);

    T getData();

    List<TreeNode<T>> getChildren();

    TreeNode<T> getParent();

    void setParent(TreeNode<T> treeNode);

    boolean isExpanded();

    void setExpanded(boolean expanded);

    int getChildCount();

    boolean isLeaf();

    boolean isSelected();

    void setSelected(boolean value);

    boolean isSelectable();

    void setSelectable(boolean selectable);

    boolean isPartialSelected();

    void setPartialSelected(boolean value);

    void setRowKey(String rowKey);

    String getRowKey();

    void clearParent();
}

==> primefaces-15.0.4-sources.jar: org/primefaces/model/TreeNode.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2009-2025 PrimeTek Informatics
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.primefaces.model;

public interface TreeNode<T> {

    String getType();

    void setType(String type);

    T getData();

    TreeNodeChildren<T> getChildren();

    TreeNode<T> getParent();

    void setParent(TreeNode<T> treeNode);

    boolean isExpanded();

    void setExpanded(boolean expanded);

    int getChildCount();

    boolean isLeaf();

    boolean isSelected();

    void setSelected(boolean value);

    boolean isSelectable();

    void setSelectable(boolean selectable);

    boolean isPartialSelected();

    void setPartialSelected(boolean value);

    void setRowKey(String rowKey);

    String getRowKey();

    void clearParent();
}
